==> apache-camel-4.14.2-src.zip: apache-camel-4.14.2/components/camel-telegram/src/main/java/org/apache/camel/component/telegram/util/TelegramMessageHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.telegram.util;

import org.apache.camel.Exchange;
import org.apache.camel.component.telegram.TelegramConstants;
import org.apache.camel.component.telegram.model.Update;

public final class TelegramMessageHelper {

    private TelegramMessageHelper() {
    }

    public static void populateExchange(Exchange exchange, Update update) {
        if (update.getMessage() != null) {
            exchange.getMessage().setBody(update.getMessage());

            if (update.getMessage().getChat() != null) {
                exchange.getMessage().setHeader(TelegramConstants.TELEGRAM_CHAT_ID, update.getMessage().getChat().getId());
            }
            if (update.getMessage().getDate() != null) {
                // convert seconds to millis
                exchange.getMessage().setHeader(TelegramConstants.MESSAGE_TIMESTAMP,
                        update.getMessage().getDate().getEpochSecond() * 1000);
            }
        } else if (update.getChannelPost() != null) {
            exchange.getMessage().setBody(update.getChannelPost());

            if (update.getChannelPost().getChat() != null) {
                exchange.getMessage().setHeader(TelegramConstants.TELEGRAM_CHAT_ID, update.getChannelPost().getChat().getId());
            }
            if (update.getChannelPost().getDate() != null) {
                // convert seconds to millis
                exchange.getMessage().setHeader(TelegramConstants.MESSAGE_TIMESTAMP,
                        update.getChannelPost().getDate().getEpochSecond() * 1000);
            }
        } else if (update.getCallbackQuery() != null) {
            exchange.getMessage().setBody(update.getCallbackQuery());
        } else if (update.getIncomingInlineQuery() != null) {
            exchange.getMessage().setBody(update.getIncomingInlineQuery());
        }

    }

}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-telegram/src/main/java/org/apache/camel/component/telegram/util/TelegramMessageHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.telegram.util;

import org.apache.camel.Exchange;
import org.apache.camel.component.telegram.TelegramConstants;
import org.apache.camel.component.telegram.model.Update;

public final class TelegramMessageHelper {

    private TelegramMessageHelper() {
    }

    public static void populateExchange(Exchange exchange, Update update) {
        if (update.getMessage() != null) {
            exchange.getMessage().setBody(update.getMessage());

            if (update.getMessage().getChat() != null) {
                exchange.getMessage().setHeader(TelegramConstants.TELEGRAM_CHAT_ID, update.getMessage().getChat().getId());
            }
            if (update.getMessage().getDate() != null) {
                // convert seconds to millis
                exchange.getMessage().setHeader(TelegramConstants.MESSAGE_TIMESTAMP,
                        update.getMessage().getDate().getEpochSecond() * 1000);
            }
        } else if (update.getChannelPost() != null) {
            exchange.getMessage().setBody(update.getChannelPost());

            if (update.getChannelPost().getChat() != null) {
                exchange.getMessage().setHeader(TelegramConstants.TELEGRAM_CHAT_ID, update.getChannelPost().getChat().getId());
            }
            if (update.getChannelPost().getDate() != null) {
                // convert seconds to millis
                exchange.getMessage().setHeader(TelegramConstants.MESSAGE_TIMESTAMP,
                        update.getChannelPost().getDate().getEpochSecond() * 1000);
            }
        } else if (update.getCallbackQuery() != null) {
            exchange.getMessage().setBody(update.getCallbackQuery());
        } else if (update.getIncomingInlineQuery() != null) {
            exchange.getMessage().setBody(update.getIncomingInlineQuery());
        } else if (update.getPreCheckoutQuery() != null) {
            exchange.getMessage().setBody(update.getPreCheckoutQuery());
        } else if (update.getShippingQuery() != null) {
            exchange.getMessage().setBody(update.getShippingQuery());
        }

    }

}
